@@ -7,12 +7,46 @@ use Carp;
 require Reddit::Client::VotableThing;
 
 use base   qw/Reddit::Client::VotableThing/;
-use fields qw/link_flair_text media url link_flair_css_class num_reports
-              created_utc banned_by subreddit title author_flair_text is_self
-              author media_embed author_flair_css_class selftext domain
-              num_comments clicked saved thumbnail subreddit_id approved_by
-              selftext_html created hidden over_18 permalink morecomments
-		user_reports mod_reports crosspost_parent/;
+use fields qw/
+approved_by
+author
+author_flair_css_class
+author_flair_text
+banned_by
+can_mod_post
+clicked
+created
+created_utc
+crosspost_parent
+domain
+hidden
+is_self
+link_flair_css_class
+link_flair_text
+locked
+media
+media_embed
+mod_reports
+morecomments
+num_comments
+num_reports
+over_18
+permalink
+quarantine
+removed
+saved
+selftext
+selftext_html
+spam
+spoiler
+stickied
+subreddit
+subreddit_id
+thumbnail
+title
+url
+user_reports
+/;
 
 use constant type => "t3";
 
